BTree

Struct BTree 

pub struct BTree<TKey, TValue, TConfig>
where TKey: Ord, TConfig: BTreeConfig,
{ /* private fields */ }
The main data structure for the B-tree algorithm.

Implementations

Source

impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>
where TKey: Ord, TConfig: BTreeConfig,

pub fn new() -> Self
where TConfig: Default,

Creates a new BTree with the default configuration.

Note: this method doesn’t allocate anything.

pub fn with_config(config: TConfig) -> Self

Creates a new BTree with the specified configuration.

Note: this method doesn’t allocate anything.

pub const fn len(&self) -> Length

Returns the number of key-value pairs in the BTree.

Source

impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>
where TKey: Ord, TConfig: BTreeConfig,

pub fn try_insert_or_update( &mut self, key: TKey, adder: impl FnOnce() -> TValue, updater: impl FnOnce(&mut TValue), ) -> Result<&mut TValue, BTreeError>

Inserts a (key, adder()) pair into the tree if it doesn’t exist, or updates the value with update(value) call.

Notes
  • If the key already exists, then this method discards key.
  • This method guarantees that either adder or updater will be called, but not both.
Errors

See BTreeError for details.

pub fn try_insert( &mut self, key: TKey, value: TValue, ) -> Result<Option<TValue>, BTreeError>

Inserts a (key, value) pair into the tree.

Returns None if the key was not already present, or the previous value if it was.

Notes

This method discards key if it already exists.

Errors

See BTreeError for details.

Source

impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>
where TKey: Ord, TConfig: BTreeConfig,

pub fn iter(&self) -> impl Iterator<Item = KVP<&TKey, &TValue>>

Iterates over the tree in ascending order.

pub fn iter_mut(&mut self) -> impl Iterator<Item = KVP<&TKey, &mut TValue>>

Iterates over the tree in ascending order.

Source

impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>
where TKey: Ord, TConfig: BTreeConfig,

pub fn remove<Q>(&mut self, key: &Q) -> Option<KVP<TKey, TValue>>
where TKey: Borrow<Q>, Q: Ord + ?Sized,

Removes a key-value pair from the BTree.

Returns the removed key-value pair if the key was present, otherwise None.

Source

impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>
where TKey: Ord, TConfig: BTreeConfig,

pub fn get<Q>(&self, key: &Q) -> Option<KVP<&TKey, &TValue>>
where TKey: Borrow<Q>, Q: Ord + ?Sized,

Returns the key-value pair with key matching the given key. Return None if the key is not present in the BTree.