pub struct BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,{ /* private fields */ }Expand description
The main data structure for the B-tree algorithm.
Implementations
Sourceimpl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
Sourceimpl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
Sourcepub fn try_insert_or_update(
&mut self,
key: TKey,
adder: impl FnOnce() -> TValue,
updater: impl FnOnce(&mut TValue),
) -> Result<&mut TValue, BTreeError>
pub fn try_insert_or_update( &mut self, key: TKey, adder: impl FnOnce() -> TValue, updater: impl FnOnce(&mut TValue), ) -> Result<&mut TValue, BTreeError>
Inserts a (key, adder()) pair into the tree if it doesn’t exist, or updates the value
with update(value) call.
Notes
- If the key already exists, then this method discards
key. - This method guarantees that either
adderorupdaterwill be called, but not both.
Errors
See BTreeError for details.
Sourcepub fn try_insert(
&mut self,
key: TKey,
value: TValue,
) -> Result<Option<TValue>, BTreeError>
pub fn try_insert( &mut self, key: TKey, value: TValue, ) -> Result<Option<TValue>, BTreeError>
Inserts a (key, value) pair into the tree.
Returns None if the key was not already present, or the previous value if it was.
Notes
This method discards key if it already exists.
Errors
See BTreeError for details.
Sourceimpl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
Sourceimpl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
Sourceimpl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,
impl<TKey, TValue, TConfig> BTree<TKey, TValue, TConfig>where
TKey: Ord,
TConfig: BTreeConfig,